import 'dart:convert';

import 'package:file_picker/file_picker.dart';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_core/ui/component/nui_toast.dart';
import 'package:nui_core/ui/nui_navigator.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_enum.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_message.dart';

class NUIMiniProgramActionUtil{

  Future<NUIMiniProgramFile> _selectFile() async{
    FilePickerResult result = await FilePicker.platform.pickFiles(
      allowedExtensions: ['jpg', 'pdf', 'doc', 'png'],
    );

    if(result != null) {
      final selected = result.files[0];
      print("NUIMiniProgramActionUtil: Selected file : $selected, path : ${selected?.path}, bytes: ${selected?.bytes?.length}");
      return NUIMiniProgramFile(filename: selected.name, bytes: selected.bytes);
    } else {
      return null;
    }
  }

  Future<NUIMiniProgramMessage> processAction(BuildContext context, String message, NUIMiniProgramMessage msg, {Function initializeListener}) async{
    try {
      final internalMessage = NUIMiniProgramInternalMessage().fromJson(jsonDecode(message));
      switch(internalMessage.type){
        case NUIMiniProgramEventType.POP: {
          pop(context);
          return null;
        }
        case NUIMiniProgramEventType.TOAST: {
          toast(message, context: context);
          return null;
        }
        case NUIMiniProgramEventType.FILE_SELECT: {
          final selectedFile = await _selectFile();
          return msg.response(data: jsonEncode(selectedFile));
        }
        case NUIMiniProgramEventType.HIDE_KEYBOARD: {
          FocusScope.of(context).unfocus();
          return null;
        }
        case NUIMiniProgramEventType.STATUS_BAR_LIGHT: {
          NUIDisplayUtil.setStatusBarStyleAttr(NUIOverlayStyle(darkStatusBarIcon: false), internal: true);
          return null;
        }
        case NUIMiniProgramEventType.STATUS_BAR_DARK: {
          NUIDisplayUtil.setStatusBarStyleAttr(NUIOverlayStyle(darkStatusBarIcon: true), internal: true);
          return null;
        }
        case NUIMiniProgramEventType.INITIALIZED: {
          if(initializeListener != null) initializeListener();
          return null;
        }
      }
    }catch(e){
      logNUI("NUIMiniProgramActionUtil", "Failed to parse NUIMiniProgramInternalMessage with error : $e");
    }
    return null;
  }

}